pub fn parse_program<'slice, 'src>(
input: Input<'slice, 'src, LustreLang>,
) -> RootIResult<'slice, 'src, LustreLang, ParserError, ParserError>Expand description
Parses en entire Lustre file (entry point to the rustre nom parser)
Tolerated syntax errors
- Top level declarations may be in the wrong order (i.e.
includeat the end of a file), and some mutually exclusive top-level declarations may be present at the same time